==> react_image_annotate_ns_workflow-1.0.5.tgz: package/LazyBrush/BrushPoup.js <==
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import CheckIcon from "@mui/icons-material/Check";
import TrashIcon from "@mui/icons-material/Delete";
import LockIcon from "@mui/icons-material/Lock";
import WarningAmberIcon from "@mui/icons-material/WarningAmber";
import { makeStyles } from "@mui/styles";
import PreventScrollToParents from "../PreventScrollToParents";
import { Button, // createTheme,
IconButton, // makeStyles,
Paper, Tooltip } from "@mui/material"; // import { ThemeProvider } from "@mui/styles"

import ClickAwayListener from "@mui/material/ClickAwayListener";
import { createTheme, ThemeProvider } from "@mui/material/styles";
import classnames from "classnames";
import React, { useState } from "react";
import CreatableSelect from "react-select/creatable";
import { asMutable } from "seamless-immutable";
import colors from "../colors";
import styles from "../RegionLabel/styles";
var theme = createTheme();
var useStyles = makeStyles(function (theme) {
  return styles;
});

function BrushPopup(_ref) {
  var top = _ref.top,
      left = _ref.left,
      showTags = _ref.showTags,
      lines = _ref.lines,
      lazyBrushClassification = _ref.lazyBrushClassification,
      lazyBrushTags = _ref.lazyBrushTags,
      setLines = _ref.setLines,
      scale = _ref.scale,
      invaild_show = _ref.invaild_show,
      delete_annotation = _ref.delete_annotation,
      setdelete_annotation = _ref.setdelete_annotation,
      annotationType = _ref.annotationType,
      videoTime = _ref.videoTime,
      mouseEvents = _ref.mouseEvents,
      isReadingMode = _ref.isReadingMode,
      setTegged = _ref.setTegged,
      setLoacal_id = _ref.setLoacal_id,
      handleMouseUp = _ref.handleMouseUp,
      convertHextoRgb = _ref.convertHextoRgb,
      setbrushHighlight = _ref.setbrushHighlight;

  var getRandomId = function getRandomId() {
    return Math.random().toString().split(".")[1];
  };

  var classes = useStyles();

  var _useState = useState(-1),
      _useState2 = _slicedToArray(_useState, 2),
      open = _useState2[0],
      setOpen = _useState2[1];

  var handleClickAway = function handleClickAway() {// setOpen(-1)
  };

  window.brushHighlighted = function (value) {
    setOpen(value);
  };

  var popUpPos = function popUpPos(_ref2) {
    var index = _ref2.index,
        top = _ref2.top;
    var labelBoxHeight = open === index ? 170 : 60; // console.log(pbox.y, labelBoxHeight)

    var displayOnTop = top > labelBoxHeight;
    return displayOnTop;
  };

  return /*#__PURE__*/React.createElement(ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/React.createElement(ClickAwayListener, {
    onClickAway: handleClickAway
  }, /*#__PURE__*/React.createElement("div", {
    onMouseUp: function onMouseUp() {
      return handleMouseUp();
    }
  }, showTags && (lines === null || lines === void 0 ? void 0 : lines.map(function (item, index) {
    var _item$popUp3, _item$color, _item$popUp4, _item$popUp5, _item$popUp5$tags;

    return item.isPopupShow === true && item.tool === "pen" && !item.isHide && /*#__PURE__*/React.createElement("div", {
      style: {
        left: "".concat(item.points[0] * scale, "px"),
        top: "".concat(item.points[1] * scale, "px"),
        position: "absolute",
        width: "200px",
        opacity: 1
      },
      onMouseDown: function onMouseDown(e) {
        return e.preventDefault();
      },
      onMouseUp: function onMouseUp(e) {
        return e.preventDefault();
      },
      onMouseEnter: function onMouseEnter(e) {
        if (open === index) {
          mouseEvents.onMouseUp(e);
          e.button = 1;
          mouseEvents.onMouseUp(e);
        }
      }
    }, /*#__PURE__*/React.createElement(PreventScrollToParents, {
      key: "brushTags"
    }, /*#__PURE__*/React.createElement(Paper, {
      className: classnames(classes.regionInfo),
      style: _objectSpread({
        opacity: open === index && 1,
        zIndex: 20,
        // top: `${19.166664123535156}px`,
        // left: `${197.90878098221688}px`,
        position: "absolute",
        cursor: "pointer",
        border: !invaild_show && lines[index].invalid ? "2px solid red" : null,
        padding: 0
      }, popUpPos({
        index: index,
        top: item.points[1] * scale
      }) ? {
        bottom: 0
      } : {
        top: 0
      })
    }, open === index ? /*#__PURE__*/React.createElement("div", {
      style: {
        width: 200,
        padding: 10
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        display: "flex",
        flexDirection: "row",
        alignItems: "flex-end"
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        display: "flex",
        backgroundColor: colors[(lazyBrushClassification === null || lazyBrushClassification === void 0 ? void 0 : lazyBrushClassification.findIndex(function (dropdown) {
          var _item$popUp, _item$popUp$classific;

          return dropdown === (item === null || item === void 0 ? void 0 : (_item$popUp = item.popUp) === null || _item$popUp === void 0 ? void 0 : (_item$popUp$classific = _item$popUp.classification) === null || _item$popUp$classific === void 0 ? void 0 : _item$popUp$classific.label);
        })) % colors.length] || "red",
        color: "#fff",
        padding: 4,
        paddingLeft: 8,
        paddingRight: 8,
        borderRadius: 4,
        fontWeight: "bold",
        textShadow: "0px 0px 5px rgba(0,0,0,0.4)"
      }
    }, "Brush"), /*#__PURE__*/React.createElement("div", {
      style: {
        flexGrow: 1
      }
    }), /*#__PURE__*/React.createElement(IconButton, {
      onClick: function onClick(e) {
        var linessave = _toConsumableArray(lines);

        var filter_arr = linessave.filter(function (filters) {
          return filters.id !== item.id && filters;
        });
        setLines(filter_arr);

        var arr = _toConsumableArray(delete_annotation);

        var delete_arr = linessave.filter(function (filter) {
          if (filter.id === item.id) {
            return filter;
          }
        }).filter(Boolean);
        arr.push(delete_arr);
        window.undoArray = [].concat(_toConsumableArray(window.undoArray), ["brush"]);
        var obj = {
          brush: delete_arr
        };

        var newArr = _toConsumableArray(window.annotation_redo);

        if (obj.brush !== undefined) {
          newArr.push(obj);
          window.annotation_redo = newArr;
        }

        setdelete_annotation(arr);
      },
      tabIndex: -1,
      style: {
        width: 22,
        height: 22
      },
      size: "small",
      variant: "outlined"
    }, /*#__PURE__*/React.createElement(TrashIcon, {
      style: {
        marginTop: -8,
        width: 16,
        height: 16
      }
    })), invaild_show && /*#__PURE__*/React.createElement(IconButton, {
      onClick: function onClick() {
        var linessave = _toConsumableArray(lines);

        var find_same_id = linessave === null || linessave === void 0 ? void 0 : linessave.map(function (items, itemIndex) {
          if (items.id === item.id) {
            lines[itemIndex].invalid = lines[itemIndex].invalid ? false : true;
          }

          return linessave;
        });
        setLines(linessave);
        window.undoArray = [].concat(_toConsumableArray(window.undoArray), ["brush"]);
      },
      tabIndex: -1,
      style: {
        width: 22,
        height: 22
      },
      size: "small",
      variant: "outlined"
    }, /*#__PURE__*/React.createElement(WarningAmberIcon, {
      style: {
        color: lines[index].invalid ? "#faad14" : "grey",
        marginTop: -8,
        width: 16,
        height: 16
      }
    }))), /*#__PURE__*/React.createElement("div", {
      style: {
        marginTop: 6
      }
    }, /*#__PURE__*/React.createElement(CreatableSelect // menuShouldBlockScroll={true}
    , {
      menuPosition: "fixed",
      menuPlacement: "auto",
      placeholder: "Classification",
      onChange: function onChange(o, actionMeta) {
        var linessave = _toConsumableArray(lines);

        var find_same_id = linessave === null || linessave === void 0 ? void 0 : linessave.map(function (items, itemIndex) {
          if (items.id === item.id) {
            lines[itemIndex].popUp.classification = o;
            lines[itemIndex].color = "rgba(".concat(convertHextoRgb(colors[(lazyBrushClassification === null || lazyBrushClassification === void 0 ? void 0 : lazyBrushClassification.findIndex(function (dropdown) {
              var _item$popUp2, _item$popUp2$classifi;

              return dropdown === (item === null || item === void 0 ? void 0 : (_item$popUp2 = item.popUp) === null || _item$popUp2 === void 0 ? void 0 : (_item$popUp2$classifi = _item$popUp2.classification) === null || _item$popUp2$classifi === void 0 ? void 0 : _item$popUp2$classifi.label);
            })) % colors.length] || "#FF0000"), ",0.5)");
          }

          return linessave;
        });
        setLines(linessave);
      },
      value: lines[index].popUp.classification,
      options: asMutable(lazyBrushClassification.map(function (c) {
        return {
          value: c,
          label: c
        };
      }))
    })), lazyBrushTags !== null && lazyBrushTags !== void 0 && lazyBrushTags.length ? /*#__PURE__*/React.createElement("div", {
      style: {
        marginTop: 4
      }
    }, /*#__PURE__*/React.createElement(CreatableSelect // menuShouldBlockScroll={true}
    , {
      menuPosition: "fixed",
      menuPlacement: "auto" // menuIsOpen={true}
      ,
      value: lines[index].popUp.tags,
      placeholder: "Tags",
      onChange: function onChange(o, actionMeta) {
        var linessave = _toConsumableArray(lines);

        var find_same_id = linessave === null || linessave === void 0 ? void 0 : linessave.map(function (items, itemIndex) {
          if (items.id === item.id) {
            var _lines$itemIndex, _lines$itemIndex$popU, _lines$itemIndex$popU2;

            lines[itemIndex].popUp.tags = o;
            lines[itemIndex].tag_count = lines === null || lines === void 0 ? void 0 : (_lines$itemIndex = lines[itemIndex]) === null || _lines$itemIndex === void 0 ? void 0 : (_lines$itemIndex$popU = _lines$itemIndex.popUp) === null || _lines$itemIndex$popU === void 0 ? void 0 : (_lines$itemIndex$popU2 = _lines$itemIndex$popU.tags) === null || _lines$itemIndex$popU2 === void 0 ? void 0 : _lines$itemIndex$popU2.length;
          }

          return linessave;
        });
        setLines(linessave);
        setLines(linessave);
        setTegged(true);
        setLoacal_id(getRandomId());
      },
      isMulti: true,
      options: asMutable(lazyBrushTags.map(function (c) {
        return {
          value: c,
          label: c
        };
      }))
    })) : null, /*#__PURE__*/React.createElement("div", {
      style: {
        marginTop: 4,
        display: "flex"
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        flexGrow: 1
      }
    }), /*#__PURE__*/React.createElement(Button, {
      onClick: function onClick() {
        if (!lines.isLocked) {
          setOpen(-1);
          setbrushHighlight(-1);
        }
      },
      size: "small",
      variant: "contained",
      color: "primary"
    }, /*#__PURE__*/React.createElement(CheckIcon, null)))) : !item.isHide && /*#__PURE__*/React.createElement("div", {
      style: {
        padding: !item.isLocked && 8
      },
      onClick: function onClick() {
        if (!lines.isLocked) {
          if (!isReadingMode) {
            !item.isLocked && setOpen(index);
            !item.isLocked && setbrushHighlight(index);
          }
        }
      }
    }, item.isLocked ? /*#__PURE__*/React.createElement(Tooltip, {
      title: "Annotate Locked"
    }, /*#__PURE__*/React.createElement(LockIcon, {
      fontSize: "small"
    })) : /*#__PURE__*/React.createElement(React.Fragment, null, (item === null || item === void 0 ? void 0 : (_item$popUp3 = item.popUp) === null || _item$popUp3 === void 0 ? void 0 : _item$popUp3.classification) && /*#__PURE__*/React.createElement("div", {
      className: "name",
      style: {
        display: "flex",
        justifyContent: "flex-start",
        alignItems: "center",
        width: "max-content"
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        backgroundColor: item === null || item === void 0 ? void 0 : (_item$color = item.color) === null || _item$color === void 0 ? void 0 : _item$color.replace("0.5", "1"),
        width: "10px",
        height: "10px",
        boxShadow: "0px 0px 2px rgb(0 0 0 / 40%)",
        marginRight: "4px",
        borderRadius: "5px"
      }
    }), /*#__PURE__*/React.createElement("span", null, item === null || item === void 0 ? void 0 : (_item$popUp4 = item.popUp) === null || _item$popUp4 === void 0 ? void 0 : _item$popUp4.classification.label)), /*#__PURE__*/React.createElement("div", {
      className: "tags"
    }, item === null || item === void 0 ? void 0 : (_item$popUp5 = item.popUp) === null || _item$popUp5 === void 0 ? void 0 : (_item$popUp5$tags = _item$popUp5.tags) === null || _item$popUp5$tags === void 0 ? void 0 : _item$popUp5$tags.map(function (t) {
      return /*#__PURE__*/React.createElement("div", {
        className: "tag"
      }, "".concat(t.label));
    })))))));
  })))));
}

export default BrushPopup;

==> react_image_annotate_ns_workflow-1.1.1.tgz: package/LazyBrush/BrushPoup.js <==
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import CheckIcon from "@mui/icons-material/Check";
import TrashIcon from "@mui/icons-material/Delete";
import LockIcon from "@mui/icons-material/Lock";
import WarningAmberIcon from "@mui/icons-material/WarningAmber";
import { Button, // createTheme,
IconButton, // makeStyles,
Paper, Tooltip } from "@mui/material";
import { makeStyles } from "@mui/styles";
import isEqual from "lodash/isEqual";
import PreventScrollToParents from "../PreventScrollToParents"; // import { ThemeProvider } from "@mui/styles"

import ClickAwayListener from "@mui/material/ClickAwayListener";
import { createTheme, ThemeProvider } from "@mui/material/styles";
import classnames from "classnames";
import React, { useMemo, useState } from "react";
import CreatableSelect from "react-select/creatable";
import { asMutable } from "seamless-immutable";
import colors from "../colors";
import styles from "../RegionLabel/styles";
var theme = createTheme();
var useStyles = makeStyles(function (theme) {
  return styles;
});

function BrushPopup(_ref) {
  var top = _ref.top,
      left = _ref.left,
      showTags = _ref.showTags,
      lines = _ref.lines,
      lazyBrushClassification = _ref.lazyBrushClassification,
      lazyBrushTags = _ref.lazyBrushTags,
      setLines = _ref.setLines,
      scale = _ref.scale,
      invaild_show = _ref.invaild_show,
      delete_annotation = _ref.delete_annotation,
      setdelete_annotation = _ref.setdelete_annotation,
      annotationType = _ref.annotationType,
      videoTime = _ref.videoTime,
      mouseEvents = _ref.mouseEvents,
      isReadingMode = _ref.isReadingMode,
      setTegged = _ref.setTegged,
      setLoacal_id = _ref.setLoacal_id,
      handleMouseUp = _ref.handleMouseUp,
      convertHextoRgb = _ref.convertHextoRgb,
      setbrushHighlight = _ref.setbrushHighlight,
      onRegionClassAdded = _ref.onRegionClassAdded,
      onRegionTagAdded = _ref.onRegionTagAdded;

  var getRandomId = function getRandomId() {
    return Math.random().toString().split(".")[1];
  };

  var classes = useStyles();

  var _useState = useState(-1),
      _useState2 = _slicedToArray(_useState, 2),
      open = _useState2[0],
      setOpen = _useState2[1];

  var handleClickAway = function handleClickAway() {// setOpen(-1)
  };

  window.brushHighlighted = function (value) {
    setOpen(value);
  };

  var popUpPos = function popUpPos(_ref2) {
    var index = _ref2.index,
        top = _ref2.top;
    var labelBoxHeight = open === index ? 170 : 60; // console.log(pbox.y, labelBoxHeight)

    var displayOnTop = top > labelBoxHeight;
    return displayOnTop;
  };

  var classification_brush = useMemo(function () {
    return asMutable(lazyBrushClassification.map(function (c) {
      return {
        value: c,
        label: c
      };
    }));
  }, [lazyBrushClassification.length]);
  var tag_brush = useMemo(function () {
    return asMutable(lazyBrushTags.map(function (c) {
      return {
        value: c,
        label: c,
        isFixed: true
      };
    }));
  }, [lazyBrushTags.length]);

  var tag_qual_check = function tag_qual_check(tagList, index) {
    var _ref3, _ref4, _lines$index;

    return isEqual((_ref3 = tagList || []) === null || _ref3 === void 0 ? void 0 : _ref3.sort(), (_ref4 = ((_lines$index = lines[index]) === null || _lines$index === void 0 ? void 0 : _lines$index.invalid_tag) || []) === null || _ref4 === void 0 ? void 0 : _ref4.sort());
  };

  return /*#__PURE__*/React.createElement(ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/React.createElement(ClickAwayListener, {
    onClickAway: handleClickAway
  }, /*#__PURE__*/React.createElement("div", {
    onMouseUp: function onMouseUp() {
      return handleMouseUp();
    }
  }, showTags && (lines === null || lines === void 0 ? void 0 : lines.map(function (item, index) {
    var _lines$index2, _lines$index2$invalid, _item$popUp3, _item$color, _item$popUp4, _item$popUp5, _item$popUp5$tags;

    return item.isPopupShow === true && item.tool === "pen" && !item.isHide && /*#__PURE__*/React.createElement("div", {
      style: {
        left: "".concat(item.points[0] * scale, "px"),
        top: "".concat(item.points[1] * scale, "px"),
        position: "absolute",
        width: "200px",
        opacity: 1
      },
      onMouseDown: function onMouseDown(e) {
        return e.preventDefault();
      },
      onMouseUp: function onMouseUp(e) {
        return e.preventDefault();
      },
      onMouseEnter: function onMouseEnter(e) {
        if (open === index) {
          mouseEvents.onMouseUp(e);
          e.button = 1;
          mouseEvents.onMouseUp(e);
        }
      }
    }, /*#__PURE__*/React.createElement(PreventScrollToParents, {
      key: "brushTags"
    }, /*#__PURE__*/React.createElement(Paper, {
      className: classnames(classes.regionInfo),
      style: _objectSpread({
        opacity: open === index && 1,
        zIndex: 20,
        // top: `${19.166664123535156}px`,
        // left: `${197.90878098221688}px`,
        position: "absolute",
        cursor: "pointer",
        border: lines[index].invalid ? lines[index].update_user ? "1px solid green" : "1px solid red" : null,
        padding: 0
      }, popUpPos({
        index: index,
        top: item.points[1] * scale
      }) ? {
        bottom: 0
      } : {
        top: 0
      })
    }, open === index ? /*#__PURE__*/React.createElement("div", {
      style: {
        width: 200,
        padding: 10
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        display: "flex",
        flexDirection: "row",
        alignItems: "flex-end"
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        display: "flex",
        backgroundColor: colors[(lazyBrushClassification === null || lazyBrushClassification === void 0 ? void 0 : lazyBrushClassification.findIndex(function (dropdown) {
          var _item$popUp, _item$popUp$classific;

          return dropdown === (item === null || item === void 0 ? void 0 : (_item$popUp = item.popUp) === null || _item$popUp === void 0 ? void 0 : (_item$popUp$classific = _item$popUp.classification) === null || _item$popUp$classific === void 0 ? void 0 : _item$popUp$classific.label);
        })) % colors.length] || "red",
        color: "#fff",
        padding: 4,
        paddingLeft: 8,
        paddingRight: 8,
        borderRadius: 4,
        fontWeight: "bold",
        textShadow: "0px 0px 5px rgba(0,0,0,0.4)"
      }
    }, "Brush"), /*#__PURE__*/React.createElement("div", {
      style: {
        flexGrow: 1
      }
    }), /*#__PURE__*/React.createElement(IconButton, {
      onClick: function onClick(e) {
        var linessave = _toConsumableArray(lines);

        var filter_arr = linessave.filter(function (filters) {
          return filters.id !== item.id && filters;
        });
        setLines(filter_arr);

        var arr = _toConsumableArray(delete_annotation);

        var delete_arr = linessave.filter(function (filter) {
          if (filter.id === item.id) {
            return filter;
          }
        }).filter(Boolean);
        arr.push(delete_arr);
        window.undoArray = [].concat(_toConsumableArray(window.undoArray), ["brush"]);
        var obj = {
          brush: delete_arr
        };

        var newArr = _toConsumableArray(window.annotation_redo);

        if (obj.brush !== undefined) {
          newArr.push(obj);
          window.annotation_redo = newArr;
        }

        setdelete_annotation(arr);
      },
      tabIndex: -1,
      style: {
        width: 22,
        height: 22
      },
      size: "small",
      variant: "outlined"
    }, /*#__PURE__*/React.createElement(TrashIcon, {
      style: {
        marginTop: -8,
        width: 16,
        height: 16
      }
    })), invaild_show && /*#__PURE__*/React.createElement(IconButton, {
      onClick: function onClick() {
        var linessave = _toConsumableArray(lines);

        var find_same_id = linessave === null || linessave === void 0 ? void 0 : linessave.map(function (items, itemIndex) {
          if (items.id === item.id) {
            lines[itemIndex].invalid = lines[itemIndex].invalid ? false : true;
            lines[itemIndex].invalid_tag = lines[itemIndex].invalid ? lines[index].popUp.tags : [];
          }

          return linessave;
        });
        setLines(linessave);
        window.undoArray = [].concat(_toConsumableArray(window.undoArray), ["brush"]);
      },
      tabIndex: -1,
      style: {
        width: 22,
        height: 22
      },
      size: "small",
      variant: "outlined"
    }, /*#__PURE__*/React.createElement(WarningAmberIcon, {
      style: {
        color: lines[index].invalid ? "#faad14" : "grey",
        marginTop: -8,
        width: 16,
        height: 16
      }
    }))), /*#__PURE__*/React.createElement("div", {
      style: {
        marginTop: 6
      }
    }, /*#__PURE__*/React.createElement(CreatableSelect // menuShouldBlockScroll={true}
    , {
      menuPosition: "fixed",
      menuPlacement: "auto",
      placeholder: "Classification",
      onChange: function onChange(o, actionMeta) {
        if (actionMeta.action === "create-option") {
          onRegionClassAdded(o.value);
        }

        var linessave = _toConsumableArray(lines);

        var find_same_id = linessave === null || linessave === void 0 ? void 0 : linessave.map(function (items, itemIndex) {
          if (items.id === item.id) {
            lines[itemIndex].popUp.classification = o;
            lines[itemIndex].color = "rgba(".concat(convertHextoRgb(colors[(lazyBrushClassification === null || lazyBrushClassification === void 0 ? void 0 : lazyBrushClassification.findIndex(function (dropdown) {
              var _item$popUp2, _item$popUp2$classifi;

              return dropdown === (item === null || item === void 0 ? void 0 : (_item$popUp2 = item.popUp) === null || _item$popUp2 === void 0 ? void 0 : (_item$popUp2$classifi = _item$popUp2.classification) === null || _item$popUp2$classifi === void 0 ? void 0 : _item$popUp2$classifi.label);
            })) % colors.length] || "#FF0000"), ",0.5)");

            if (o) {
              lines[itemIndex].update_user = lines[itemIndex].popUp.classification === o ? false : lines[itemIndex].invalid && !invaild_show ? true : false;
            }
          }

          return linessave;
        });
        setLines(linessave);
      },
      value: lines[index].popUp.classification,
      options: classification_brush
    })), lazyBrushTags !== null && lazyBrushTags !== void 0 && lazyBrushTags.length ? /*#__PURE__*/React.createElement("div", {
      style: {
        marginTop: 4
      }
    }, /*#__PURE__*/React.createElement(CreatableSelect // menuShouldBlockScroll={true}
    , {
      component: null,
      menuPosition: "fixed",
      menuPlacement: "auto" // menuIsOpen={true}
      ,
      value: lines[index].popUp.tags,
      placeholder: "Tags",
      onChange: function onChange(o, actionMeta) {
        if (actionMeta.action === "create-option") {
          var _o$find;

          onRegionTagAdded(o === null || o === void 0 ? void 0 : (_o$find = o.find(function (item) {
            return item.__isNew__ === true;
          })) === null || _o$find === void 0 ? void 0 : _o$find.value);
        }

        var linessave = _toConsumableArray(lines);

        var find_same_id = linessave === null || linessave === void 0 ? void 0 : linessave.map(function (items, itemIndex) {
          if (items.id === item.id) {
            lines[itemIndex].popUp.tags = o;
            lines[itemIndex].tag_count = (o === null || o === void 0 ? void 0 : o.length) || 0;

            if (o !== null && o !== void 0 && o.length) {
              var qc_invaild = tag_qual_check(o, itemIndex);
              lines[itemIndex].update_user = qc_invaild ? false : lines[itemIndex].invalid && !invaild_show ? true : false;
            }
          }

          return linessave;
        });
        setLines(linessave);
        setTegged(true);
        setLoacal_id(getRandomId());
      },
      isMulti: true,
      options: tag_brush
    })) : null, !invaild_show && (_lines$index2 = lines[index]) !== null && _lines$index2 !== void 0 && (_lines$index2$invalid = _lines$index2.invalid_tag) !== null && _lines$index2$invalid !== void 0 && _lines$index2$invalid.length && tag_qual_check(lines[index].popUp.tags, index) && lazyBrushTags !== null && lazyBrushTags !== void 0 && lazyBrushTags.length ? /*#__PURE__*/React.createElement("span", null, "Enter correct data, this is marked invalid") : null, /*#__PURE__*/React.createElement("div", {
      style: {
        marginTop: 4,
        display: "flex"
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        flexGrow: 1
      }
    }), /*#__PURE__*/React.createElement(Button, {
      onClick: function onClick() {
        if (!lines.isLocked) {
          setOpen(-1);
          setbrushHighlight(-1);
        }
      },
      size: "small",
      variant: "contained",
      color: "primary"
    }, /*#__PURE__*/React.createElement(CheckIcon, null)))) : !item.isHide && /*#__PURE__*/React.createElement("div", {
      style: {
        padding: !item.isLocked && 8
      },
      onClick: function onClick() {
        if (!lines.isLocked) {
          if (!isReadingMode) {
            !item.isLocked && setOpen(index);
            !item.isLocked && setbrushHighlight(index);
          }
        }
      }
    }, item.isLocked ? /*#__PURE__*/React.createElement(Tooltip, {
      title: "Annotate Locked",
      placement: "right"
    }, /*#__PURE__*/React.createElement(LockIcon, {
      fontSize: "small"
    })) : /*#__PURE__*/React.createElement(React.Fragment, null, (item === null || item === void 0 ? void 0 : (_item$popUp3 = item.popUp) === null || _item$popUp3 === void 0 ? void 0 : _item$popUp3.classification) && /*#__PURE__*/React.createElement("div", {
      className: "name",
      style: {
        display: "flex",
        justifyContent: "flex-start",
        alignItems: "center",
        width: "max-content"
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        backgroundColor: item === null || item === void 0 ? void 0 : (_item$color = item.color) === null || _item$color === void 0 ? void 0 : _item$color.replace("0.5", "1"),
        width: "10px",
        height: "10px",
        boxShadow: "0px 0px 2px rgb(0 0 0 / 40%)",
        marginRight: "4px",
        borderRadius: "5px"
      }
    }), /*#__PURE__*/React.createElement("span", null, item === null || item === void 0 ? void 0 : (_item$popUp4 = item.popUp) === null || _item$popUp4 === void 0 ? void 0 : _item$popUp4.classification.label)), /*#__PURE__*/React.createElement("div", {
      className: "tags"
    }, item === null || item === void 0 ? void 0 : (_item$popUp5 = item.popUp) === null || _item$popUp5 === void 0 ? void 0 : (_item$popUp5$tags = _item$popUp5.tags) === null || _item$popUp5$tags === void 0 ? void 0 : _item$popUp5$tags.map(function (t) {
      return /*#__PURE__*/React.createElement("div", {
        className: "tag"
      }, "".concat(t.label));
    })))))));
  })))));
}

export default BrushPopup;
